%-------------------------------------------
% Housekeeping
%-------------------------------------------

clear
warning off

setpathdynare4
warning off

global oo00_  M00_ M10_  M01_  M11_ M_

global params_labels params

global cof cof10 cof01 cof11 ...
  Jbarmat Jbarmat10 Jbarmat01 Jbarmat11 ...
  Dbarmat10 Dbarmat01 Dbarmat11 ...
  decrulea decruleb

global filtered_errs_switch filtered_errs_init model_temp
global datavec irep xstory fstory

irep=1; datavec=[]; xstory=[]; fstory=[];

% 0: uses csolve; 1: csolve with gradient; 2: fsolve
solver=0; 


set(0,'DefaultLineLineWidth',2)
randn('seed',1);
format compact




%----------------------------------------------------------------------
% Invoke calibrated parameters
%----------------------------------------------------------------------

paramfile_cgg

LAMBDA=0.04;
BETA=0.9925;
FIP=4;
FIY=4;
FIR=0.8;
PHI=1;
RHOY=0.5;

save PARAM_EXTRA_CALIBRATED LAMBDA BETA FIP FIY FIR PHI RHOY

% Indicator variable set 1 if priors are used or not
IPRIOR=0;

params_matrix = {  ...
  'RHOY '    0.500000  -0.9999 	 0.9999     1     'NORMAL_PDF'    0    0.5
  'STD_P '   0.001000   0.0001   0.9999     1     'INV_GAMMA_PDF' 0.01 1
  'STD_R '   0.001000   0.0001   0.9999     1     'INV_GAMMA_PDF' 0.01 1
  'STD_Y '   0.010000   0.0001   0.9999     1     'INV_GAMMA_PDF' 0.01 1
  } ;

save params_matrix params_matrix



err_list = char('eps_p','eps_r','eps_y');

H0 = diag(cell2mat(params_matrix(:,5)).^2) ;

params_labels = params_matrix(:,1);
params0 =   cell2mat(params_matrix(:,2));
params_lo = cell2mat(params_matrix(:,3));
params_hi = cell2mat(params_matrix(:,4));
params_mean = cell2mat(params_matrix(:,7));
params_std = cell2mat(params_matrix(:,8));

dist_names = params_matrix(:,6);
codes = dist_names2codes(dist_names);
[p6 p7] = get_dist_inputs(codes,params_mean,params_std);

% myplot_priors(codes,params_lo,params_hi,p6,p7,params_labels)

% for i=1:numel(p6)
% [logged_prior_density(i)] = priordens(params0(i), codes(i), p6(i), p7(i), params_lo(i), params_hi(i),1)
% end


for i=1:numel(params_labels)
  evalc([ cell2mat(params_labels(i)) '= params0(' num2str(i) ')']) ;
end






%-------------------------------
% Load data and Declare observables
%-------------------------------
 
load fakedata
tstar=1;
obs_list = char('p','rlong','y');
obs=[ p_p rlong_p y_p ];
obs=obs(1:end,:);
tt_obs = (1:size(obs,1))';
ntrain = 1;




%-----------------------------------
% Create script to speed up filtering
%-----------------------------------

modnam_00 = 'cgg'; % base model (constraint 1 and 2 below don't bind)
modnam_10 = 'cgg_zlb'; % first constraint is true
modnam_01 = 'cgg'; % second constraint is true
modnam_11 = 'cgg'; % both constraints bind
constraint1 = 'r<(1-1/BETA)';
constraint_relax1 = 'rnot>(1-1/BETA)';
constraint2 = 'r<(1-1/BETA)-10000000';
constraint_relax2 = 'r<(1-1/BETA)-10000000';
curb_retrench =0;
maxiter = 20;



call_pre_estimation_script



        method = 'initial_check';
%  method = 'fminsearch';
%  method = 'metropolis';


if strmatch(method,'initial_check')==1

params0=[0.500
    0.001
    0.001
    0.020];
    
%-----------------------------------
% Check value of the likelihood at the initial guess
%-----------------------------------

 params1=params0;

  [posterior filtered_errs like prior resids ]=...
      posterior1(params1,params_labels,params_lo,params_hi,...
   modnam_00,modnam_10,modnam_01,modnam_11,...
   constraint1_difference, constraint2_difference,...
   constraint_relax1_difference, constraint_relax2_difference,...
   err_list,obs_list,obs,ntrain,codes, p6, p7,IPRIOR,solver);

  params=params0;
  sample_length = size(obs,1);
      
  save mle_initial_check

  run_feed_filtered_shocks_back

end      



if strmatch(method,'fminsearch')==1
  
%-----------------------------------
% Maximize likelihood using fminsearch
%-----------------------------------
params0=[0.400
    0.0008
    0.0008
    0.0008];

  tolerance = 1e-5;
  options = optimset('Display','Iter','TolFun',tolerance,'TolX',tolerance,'TolFun',tolerance,...
    'MaxFunEvals',10000,'MaxIter',200,...
    'DiffMinChange',tolerance,'Algorithm','Interior-Point'); 
  IPRIOR=0;
  
  for ii=1:1
  [params,fval]=fminsearchbnd(@(current_params) posterior1...
    (current_params,params_labels,params_lo,params_hi,...
    modnam_00,modnam_10,modnam_01,modnam_11,...
    constraint1_difference, constraint2_difference,...
    constraint_relax1_difference, constraint_relax2_difference,...
    err_list,obs_list,obs,ntrain,codes,p6,p7,IPRIOR,solver),params0,params_lo,params_hi,options);
  
    params1 = params;
  
  [posterior filtered_errs like prior] = ...
    posterior1(params1,params_labels,params_lo,params_hi,...
    modnam_00,modnam_10,modnam_01,modnam_11,...
    constraint1_difference, constraint2_difference,...
    constraint_relax1_difference, constraint_relax2_difference,...
    err_list,obs_list,obs,ntrain,codes,p6,p7,IPRIOR,solver);

   eval(['save mle_estimates' num2str(ii) ' params_labels params1 filtered_errs fval obs err_list obs_list IPRIOR'])
  
  end
  
  
  run_feed_filtered_shocks_back
  
  [ hessian_reg stdh_reg hessian_fmin stdh_fmin ] = compute_hessian(xstory,fstory,30);
 
  save mle_estimates_fminsearch params_labels params1 filtered_errs fval obs err_list obs_list hessian* stdh* IPRIOR 
  
  
  
end



if strmatch(method,'metropolis')==1
    
tic    
 load mle_estimates_fminsearch 
 hessian1=diag(diag(hessian_fmin));

solver=0;
ndraws=5000;
load_switch = 0;
jump=1;

[theta_history, fval_history, accept_average] = ...
   mhalgo('posterior1',params1,hessian1,[],[],ndraws,load_switch,jump,...
   params_labels,params_lo,params_hi,...
   modnam_00,modnam_10,modnam_01,modnam_11,...
   constraint1_difference, constraint2_difference,...
   constraint_relax1_difference, constraint_relax2_difference,...
   err_list,obs_list,obs,ntrain,codes, p6, p7,IPRIOR,solver);



save metropolis_estimates

toc


end


