//% Three equations DNK model 
//% Corrected typo on 5/20/15 relative to euler equation for consumption
var aap, aar, aay, p, r, rlong, rnot, y;
varexo eps_p eps_r eps_y;

parameters BETA FIP FIY FIR LAMBDA PHI RHOY RHOR ;

model(linear);
//% IS curve (Equation 2.1 in CGG JEL 1999 paper)
y = y(+1) - PHI*(r - p(+1)) + aay ;

//% Phillips curve (Equation 2.2 in CGG JEL 1999 paper)
p = BETA*p(+1) + LAMBDA*y + eps_p ;

//% Aggregate Demand disturbance (Equation 2.3)
aay = RHOY*aay(-1) + eps_y;
aap = eps_p;
aar = RHOR*aar(-1) + eps_r;

rlong = 0.10*r + 0.90*rlong(+1);

//% Interest Rate rule (Equation 7.1)
rnot = FIR*rnot(-1) + (1-FIR)*(FIP*p + FIY*y) + aar ;
r = rnot;



end;

initval;
aap = 0;
aar = 0;
aay = 0;
p = 0;
r = 0;
rlong = 0;
rnot = 0;
y = 0;
end;


shocks;
var eps_p; stderr STD_P;
var eps_r; stderr STD_R;
var eps_y; stderr STD_Y;
end;



stoch_simul(order=1,nocorr,nomoments,noprint,irf=0);						  